package org.energy.core.config;


import com.dayu.daf.core.secure.aspect.AuthAspect;
import com.dayu.daf.core.secure.interceptor.ClientInterceptor;
import com.dayu.daf.core.secure.props.DafSecureProperties;
import com.dayu.daf.core.secure.props.DafTokenProperties;
import com.dayu.daf.core.secure.provider.ClientDetailsServiceImpl;
import com.dayu.daf.core.secure.provider.IClientDetailsService;
import com.dayu.daf.core.secure.registry.SecureRegistry;
import lombok.AllArgsConstructor;
import org.energy.core.interceptor.EnergySecureInterceptor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.annotation.Order;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

/**
 * 安全配置类
 *
 * @author Dayu
 */
@Order
@Configuration
@AllArgsConstructor
@EnableConfigurationProperties({DafSecureProperties.class, DafTokenProperties.class})
public class EnergySecureConfiguration implements WebMvcConfigurer {

	private final SecureRegistry secureRegistry;

	private final DafSecureProperties secureProperties;

	private final JdbcTemplate jdbcTemplate;

	@Autowired
	private EnergySecureInterceptor energySecureInterceptor;

	@Override
	public void addInterceptors(InterceptorRegistry registry) {
		secureProperties.getClient().forEach(cs -> registry.addInterceptor(new ClientInterceptor(cs.getClientId())).addPathPatterns(cs.getPathPatterns()));

		if (secureRegistry.isEnabled()) {
			registry.addInterceptor(energySecureInterceptor)
				.excludePathPatterns(secureRegistry.getExcludePatterns())
				.excludePathPatterns(secureRegistry.getDefaultExcludePatterns())
				.excludePathPatterns(secureProperties.getSkipUrl());
		}
	}

	@Bean
	public AuthAspect authAspect() {
		return new AuthAspect();
	}

	@Bean
	@ConditionalOnMissingBean(IClientDetailsService.class)
	public IClientDetailsService clientDetailsService() {
		return new ClientDetailsServiceImpl(jdbcTemplate);
	}

}
