/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.leger.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.energy.modules.smart.entity.OperationItem;
import org.energy.modules.smart.entity.OperationTicket;
import org.energy.modules.smart.entity.WorkOrder;
import org.energy.modules.smart.entity.WorkPermit;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.leger.entity.Dynamicledger;
import org.energy.modules.leger.vo.DynamicledgerVO;
import org.energy.modules.leger.service.IDynamicledgerService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.util.List;

/**
 * L_DYNAMICLEDGER 控制器
 *
 * @author Daf
 * @since 2024-07-17
 */
@RestController
@AllArgsConstructor
@RequestMapping("/leger/dynamicledger")
@Api(value = "L_DYNAMICLEDGER", tags = "L_DYNAMICLEDGER接口")
public class DynamicledgerController extends DafController {

	private IDynamicledgerService dynamicledgerService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入dynamicledger")
	public R<Dynamicledger> detail(Dynamicledger dynamicledger) {
		Dynamicledger detail = dynamicledgerService.getOne(Condition.getQueryWrapper(dynamicledger));
		return R.data(detail);
	}

	/**
	 * 分页 L_DYNAMICLEDGER
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入dynamicledger")
	public R<IPage<Dynamicledger>> list(Dynamicledger dynamicledger, Query query) {

		IPage<Dynamicledger> pages = dynamicledgerService.selectDynamicledgerPageExt(Condition.getPage(query), dynamicledger);
		return R.data(pages);
	}

	/**
	 * 自定义分页 L_DYNAMICLEDGER
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入dynamicledger")
	public R<IPage<DynamicledgerVO>> page(DynamicledgerVO dynamicledger, Query query) {

		IPage<DynamicledgerVO> pages = dynamicledgerService.selectDynamicledgerPage(Condition.getPage(query), dynamicledger);
		return R.data(pages);
	}

	/**
	 * 新增 L_DYNAMICLEDGER
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入dynamicledger")
	public R save(@Valid @RequestBody Dynamicledger dynamicledger) {
		return R.status(dynamicledgerService.save(dynamicledger));
	}

	/**
	 * 修改 L_DYNAMICLEDGER
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入dynamicledger")
	public R update(@Valid @RequestBody Dynamicledger dynamicledger) {
		return R.status(dynamicledgerService.updateById(dynamicledger));
	}

	/**
	 * 新增或修改 L_DYNAMICLEDGER
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入dynamicledger")
	public R submit(@Valid @RequestBody Dynamicledger dynamicledger) {
		return R.status(dynamicledgerService.saveOrUpdate(dynamicledger));
	}


	/**
	 * 删除 L_DYNAMICLEDGER
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(dynamicledgerService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 工单
	 */
	@GetMapping("/workOrder")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "分页", notes = "传入dynamicledger")
	public R<List<WorkOrder>> getWorkOrederList(Dynamicledger dynamicledger) {
		List<WorkOrder> list = dynamicledgerService.getWorkOrederListbyKksCd(dynamicledger);
		return R.data(list);
	}
	/**
	 * 工作票
	 */
	@GetMapping("/workticket")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "分页", notes = "传入dynamicledger")
	public R<List<WorkPermit>> getWorkticketList(Dynamicledger dynamicledger) {
		List<WorkPermit> list = dynamicledgerService.getWorkticketListbyKksCd(dynamicledger);
		return R.data(list);
	}
	/**
	 * 操作票
	 */
	@GetMapping("/operation")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "分页", notes = "传入dynamicledger")
	public R<List<OperationTicket>> getoOperationList(Dynamicledger dynamicledger) {
		List<OperationTicket> list = dynamicledgerService.getOperationListbyKksCd( dynamicledger);
		return R.data(list);
	}

}
