/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.leger.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.energy.modules.system.entity.Dict;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.leger.entity.TechParameters;
import org.energy.modules.leger.vo.TechParametersVO;
import org.energy.modules.leger.service.ITechParametersService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.util.List;

/**
 * 技术参数一览 控制器
 *
 * @author Daf
 * @since 2024-07-04
 */
@RestController
@AllArgsConstructor
@RequestMapping("/techparameters")
@Api(value = "技术参数一览", tags = "技术参数一览接口")
public class TechParametersController extends DafController {

	private ITechParametersService techParametersService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入techParameters")
	public R<TechParameters> detail(TechParameters techParameters) {
		TechParameters detail = techParametersService.getOne(Condition.getQueryWrapper(techParameters));
		return R.data(detail);
	}

	/**
	 * 分页 技术参数一览
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入techParameters")
	public R<IPage<TechParameters>> list(TechParameters techParameters, Query query) {
		IPage<TechParameters> pages = techParametersService.page(Condition.getPage(query), Condition.getQueryWrapper(techParameters));
		return R.data(pages);
	}

	/**
	 * 自定义分页 技术参数一览
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入techParameters")
	public R<IPage<TechParametersVO>> page(TechParametersVO techParameters, Query query) {
		IPage<TechParametersVO> pages = techParametersService.selectTechParametersPage(Condition.getPage(query), techParameters);
		return R.data(pages);
	}

	/**
	 * 新增 技术参数一览
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入techParameters")
	public R save(@Valid @RequestBody TechParameters techParameters) {
		return R.status(techParametersService.save(techParameters));
	}

	/**
	 * 修改 技术参数一览
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入techParameters")
	public R update(@Valid @RequestBody TechParameters techParameters) {
		return R.status(techParametersService.updateById(techParameters));
	}

	/**
	 * 新增或修改 技术参数一览
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入techParameters")
	public R submit(@Valid @RequestBody TechParameters techParameters) {
		return R.status(techParametersService.saveOrUpdate(techParameters));
	}


	/**
	 * 删除 技术参数一览
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(techParametersService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 列表 技术参数一览
	 */
	@GetMapping("/getList")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "列表", notes = "传入techParameters")
	public R<List<TechParameters>> getList(TechParameters techParameters) {
		List<TechParameters> list = techParametersService.list(Condition.getQueryWrapper(techParameters));
		return R.data(list);
	}

	/**
	 * 删除 技术参数一览
	 */
	@GetMapping("/del")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "逻辑删除", notes = "传入eqLedgerId")
	public R del(@ApiParam(value = "主键集合", required = true) @RequestParam Long eqLedgerId) {
		return R.status(techParametersService.delTechParameters(eqLedgerId));
	}
}
