/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.leger.controller;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.dayu.daf.core.boot.ctrl.DafController;
import com.dayu.daf.core.log.annotation.ApiLog;
import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.constant.DafConstant;
import com.dayu.daf.core.tool.utils.Func;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.xkcoding.http.util.StringUtil;
import io.micrometer.core.instrument.util.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import lombok.SneakyThrows;
import org.apache.commons.codec.Charsets;
import org.energy.modules.leger.entity.EquipmentLedger;
import org.energy.modules.leger.excel.EquipmentLedgerExcel;
import org.energy.modules.leger.service.IEquipmentLedgerService;
import org.energy.modules.leger.service.IInventoryDocumentService;
import org.energy.modules.leger.service.ITechParametersService;
import org.energy.modules.leger.vo.EquipmentLedgerVO;
import org.energy.modules.system.util.DataUtils;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 设备台账编码一览 控制器
 *
 * @author Daf
 * @since 2024-07-04
 */
@RestController
@AllArgsConstructor
@RequestMapping("/postmanagement")
@Api(value = "设备台账编码一览", tags = "设备台账编码一览接口")
public class postmanagementController extends DafController {

	private IEquipmentLedgerService equipmentLedgerService;
	private IInventoryDocumentService inventoryDocumentService;
	private ITechParametersService techParametersService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入equipmentLedger")
	public R<EquipmentLedger> detail(EquipmentLedger equipmentLedger) {
		EquipmentLedger detail = equipmentLedgerService.getOne(Condition.getQueryWrapper(equipmentLedger));
		return R.data(detail);
	}

	/**
	 * 分页 设备台账编码一览
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入equipmentLedger")
	public R<IPage<EquipmentLedger>> list(EquipmentLedger equipmentLedger, Query query) {
		QueryWrapper<EquipmentLedger> qw = new QueryWrapper<>();
		qw.orderByAsc("eq_ledger_code");
		if (StringUtil.isNotEmpty(equipmentLedger.getMajor())) {
			qw.lambda().like(EquipmentLedger::getMajor, equipmentLedger.getMajor());
		}
		if (null != equipmentLedger.getUserStatus()) {
			qw.lambda().eq(EquipmentLedger::getUserStatus, equipmentLedger.getUserStatus());
		}
		if (null != equipmentLedger.getStation()) {
			qw.lambda().eq(EquipmentLedger::getStation, equipmentLedger.getStation());
		}
		if (StringUtil.isNotEmpty(equipmentLedger.getInstallationLocation())) {
			qw.lambda().like(EquipmentLedger::getInstallationLocation, equipmentLedger.getInstallationLocation());
		}
		if (StringUtil.isNotEmpty(equipmentLedger.getEqLedgerCode())) {
			qw.lambda().like(EquipmentLedger::getEqLedgerCode, equipmentLedger.getEqLedgerCode());
		}
		if (StringUtil.isNotEmpty(equipmentLedger.getDeviceDescription())) {
			qw.lambda().like(EquipmentLedger::getDeviceDescription, equipmentLedger.getDeviceDescription());
		}
		if (StringUtil.isNotEmpty(equipmentLedger.getEqType())) {
			qw.lambda().like(EquipmentLedger::getEqType, equipmentLedger.getEqType());
		}
		if (StringUtil.isNotEmpty(equipmentLedger.getMaintenanceTeam())) {
			qw.lambda().like(EquipmentLedger::getMaintenanceTeam, equipmentLedger.getMaintenanceTeam());
		}
		if (StringUtil.isNotEmpty(equipmentLedger.getManufacturingSerialNo())) {
			qw.lambda().like(EquipmentLedger::getManufacturingSerialNo, equipmentLedger.getManufacturingSerialNo());
		}
		IPage<EquipmentLedger> pages = equipmentLedgerService.page(Condition.getPage(query), qw);

		return R.data(pages);
	}

	/**
	 * 自定义分页 设备台账编码一览
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入equipmentLedger")
	public R<IPage<EquipmentLedgerVO>> page(EquipmentLedgerVO equipmentLedger, Query query) {
		IPage<EquipmentLedgerVO> pages = equipmentLedgerService.selectEquipmentLedgerPage(Condition.getPage(query), equipmentLedger);
		return R.data(pages);
	}

	/**
	 * 新增 设备台账编码一览
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入equipmentLedger")
	public R save(@Valid @RequestBody EquipmentLedger equipmentLedger) {
		return R.status(equipmentLedgerService.save(equipmentLedger));
	}

	/**
	 * 修改 设备台账编码一览
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入equipmentLedger")
	public R update(@Valid @RequestBody EquipmentLedger equipmentLedger) {
		return R.status(equipmentLedgerService.updateById(equipmentLedger));
	}

	/**
	 * 新增或修改 设备台账编码一览
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入equipmentLedger")
	public R submit(@Valid @RequestBody EquipmentLedger equipmentLedger) {
		return R.status(equipmentLedgerService.saveOrUpdate(equipmentLedger));
	}


	/**
	 * 删除 设备台账编码一览
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		for (String id : ids.split(",")) {
			inventoryDocumentService.delInventoryDocument(Long.parseLong(id));
			techParametersService.delTechParameters(Long.parseLong(id));
		}
		return R.status(equipmentLedgerService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 驳回OR审核 设备台账编码一览
	 */
	public R approve(Integer status, String ids) {
		List<EquipmentLedger> list = new ArrayList<>();
		for (String id : ids.split(",")) {
			EquipmentLedger equipmentLedger = equipmentLedgerService.getById(Long.parseLong(id));
			equipmentLedger.setCheckStatus(status);
			list.add(equipmentLedger);
		}
		return R.status(equipmentLedgerService.updateBatchById(list));
	}

	/**
	 * 获取对象编号
	 */
	@GetMapping("/getKksList")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "获取kks编号", notes = "获取kks编号")
	public R<List<EquipmentLedger>> getKksNoList() {
		List<EquipmentLedger> kksList = equipmentLedgerService.getKksNoList();
		return R.data(kksList);
	}

	/**
	 * 获取对象编号
	 */
	@GetMapping("/getDetailList")
	@ApiOperationSupport(order = 12)
	@ApiOperation(value = "获取kks信息", notes = "获取kks信息")
	public R<EquipmentLedger> getDetailList(String KksNo) {
		EquipmentLedger DetailList = equipmentLedgerService.getDetailList("'" + KksNo + "'");
		return R.data(DetailList);
	}

	/**
	 * 远程搜索
	 */
	@GetMapping("/listByCoding")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "远程搜索", notes = "传入")
	public R<List<EquipmentLedger>> listByCoding(String coding) {
		QueryWrapper<EquipmentLedger> queryWrapper = new QueryWrapper<>();
		if (StringUtils.isNotEmpty(coding)) {
			if (coding.matches("\\d+")) {
				queryWrapper.nested(wrapper -> wrapper.eq("id", Long.parseLong(coding))
					.or().lambda().like(EquipmentLedger::getKksEncoding, coding));
			} else {
				queryWrapper.lambda().like(EquipmentLedger::getKksEncoding, coding);
			}
		}
		queryWrapper.lambda().eq(EquipmentLedger::getCheckStatus, 2);
		queryWrapper.lambda().eq(EquipmentLedger::getIsDeleted, DafConstant.DB_NOT_DELETED);
		queryWrapper.lambda().orderByAsc(EquipmentLedger::getKksEncoding);
		queryWrapper.lambda().last(" LIMIT 50");
		List<EquipmentLedger> list = equipmentLedgerService.list(queryWrapper);

		return R.data(list);
	}

	/**
	 * 获取kkskey
	 */
	@GetMapping("/getKksKey")
	@ApiOperationSupport(order = 12)
	@ApiOperation(value = "获取kks编号", notes = "获取kks编号")
	public R<EquipmentLedger>  getKksKey(String KksNo) {
		EquipmentLedger DetailList = equipmentLedgerService.getKksKey("'" + KksNo + "'");
		return R.data(DetailList);
	}

	/**
	 * 获取kkskey
	 */
	@GetMapping("/getEqLedgerCode")
	@ApiOperationSupport(order = 13)
	@ApiOperation(value = "获取kks编号", notes = "获取kks编号")
	public R<EquipmentLedger> getEqLedgerCode(String eqLedgerCode) {
		EquipmentLedger DetailList = equipmentLedgerService.getEqLedgerCode("'" + eqLedgerCode + "'");
		return R.data(DetailList);
	}
}
