/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.master.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.master.entity.HistoryRecord;
import org.energy.modules.master.vo.HistoryRecordVO;
import org.energy.modules.master.service.IHistoryRecordService;
import com.dayu.daf.core.boot.ctrl.DafController;

/**
 * 历史记录 控制器
 *
 * @author Daf
 * @since 2025-01-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("/master/historyrecord")
@Api(value = "历史记录", tags = "历史记录接口")
public class HistoryRecordController extends DafController {

	private IHistoryRecordService historyRecordService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入historyRecord")
	public R<HistoryRecord> detail(HistoryRecord historyRecord) {
		HistoryRecord detail = historyRecordService.selectDetail(historyRecord.getHistoryNumber());
		return R.data(detail);
	}

	/**
	 * 分页 历史记录
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入historyRecord")
	public R<IPage<HistoryRecord>> list(HistoryRecord historyRecord, Query query) {
		IPage<HistoryRecord> pages = historyRecordService.page(Condition.getPage(query), Condition.getQueryWrapper(historyRecord));
		return R.data(pages);
	}

	/**
	 * 自定义分页 历史记录
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入historyRecord")
	public R<IPage<HistoryRecordVO>> page(HistoryRecordVO historyRecord, Query query) {
		IPage<HistoryRecordVO> pages = historyRecordService.selectHistoryRecordPage(Condition.getPage(query), historyRecord);
		return R.data(pages);
	}

	/**
	 * 新增 历史记录
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入historyRecord")
	public R save(@Valid @RequestBody HistoryRecord historyRecord) {
		return R.status(historyRecordService.save(historyRecord));
	}

	/**
	 * 修改 历史记录
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入historyRecord")
	public R update(@Valid @RequestBody HistoryRecord historyRecord) {
		return R.status(historyRecordService.updateById(historyRecord));
	}

	/**
	 * 新增或修改 历史记录
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入historyRecord")
	public R submit(@Valid @RequestBody HistoryRecord historyRecord) {
		return R.status(historyRecordService.saveOrUpdate(historyRecord));
	}


	/**
	 * 删除 历史记录
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(historyRecordService.deleteLogic(Func.toLongList(ids)));
	}


}
