/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.org.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.energy.modules.org.vo.PositionInfoVO;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.org.entity.DepartmentInfo;
import org.energy.modules.org.vo.DepartmentInfoVO;
import org.energy.modules.org.service.IDepartmentInfoService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.util.List;

/**
 * 部门信息 控制器
 *
 * @author Daf
 * @since 2024-12-26
 */
@RestController
@AllArgsConstructor
@RequestMapping("/org/departmentinfo")
@Api(value = "部门信息", tags = "部门信息接口")
public class DepartmentInfoController extends DafController {

	private IDepartmentInfoService departmentInfoService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入departmentInfo")
	public R<DepartmentInfo> detail(DepartmentInfo departmentInfo) {
		DepartmentInfo detail = departmentInfoService.selectDetail(departmentInfo.getId());
		return R.data(detail);
	}

	/**
	 * 分页 部门信息
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入departmentInfo")
	public R<IPage<DepartmentInfo>> list(DepartmentInfo departmentInfo, Query query) {
		IPage<DepartmentInfo> pages = departmentInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(departmentInfo));
		return R.data(pages);
	}

	/**
	 * 自定义分页 部门信息
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入departmentInfo")
	public R<IPage<DepartmentInfoVO>> page(DepartmentInfoVO departmentInfo, Query query) {
		IPage<DepartmentInfoVO> pages = departmentInfoService.selectDepartmentInfoPage(Condition.getPage(query), departmentInfo);
		return R.data(pages);
	}

	/**
	 * 新增 部门信息
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入departmentInfo")
	public R save(@Valid @RequestBody DepartmentInfo departmentInfo) {
		return R.status(departmentInfoService.save(departmentInfo));
	}

	/**
	 * 修改 部门信息
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入departmentInfo")
	public R update(@Valid @RequestBody DepartmentInfo departmentInfo) {
		return R.status(departmentInfoService.updateById(departmentInfo));
	}

	/**
	 * 新增或修改 部门信息
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入departmentInfo")
	public R submit(@Valid @RequestBody DepartmentInfo departmentInfo) {
		return R.status(departmentInfoService.saveOrUpdate(departmentInfo));
	}


	/**
	 * 删除 部门信息
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(departmentInfoService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 部門下拉列表信息
	 */
	@GetMapping("/selectDepartmentInfo")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "下拉", notes = "")
	public List<DepartmentInfoVO> departmentSelectInfo(String stationCode) {
		List<DepartmentInfoVO>  departmentInfoList= departmentInfoService.departmentInfoData(stationCode);
		return departmentInfoList;
	}

	/**
	 * 部門狀態下拉列表信息
	 */
	@GetMapping("/selectDepartmentStatusInfo")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "下拉", notes = "")
	public List<DepartmentInfoVO> departmentStatusSelectInfo(String stationCode) {
		List<DepartmentInfoVO>  departmentStatusInfoList= departmentInfoService.departmentStatusInfoData();
		return departmentStatusInfoList;
	}

}
