/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.org.controller;

import com.alibaba.excel.EasyExcel;
import com.dayu.daf.core.log.annotation.ApiLog;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import lombok.SneakyThrows;
import org.apache.commons.codec.Charsets;
import org.energy.modules.leger.excel.ToolInventoryRecordExcel;
import org.energy.modules.leger.vo.ToolInventoryRecordVO;
import org.energy.modules.org.excel.StaffInfoExcel;
import org.energy.modules.org.vo.DepartmentInfoVO;
import org.energy.modules.system.util.DataUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.org.entity.StaffInfo;
import org.energy.modules.org.vo.StaffInfoVO;
import org.energy.modules.org.service.IStaffInfoService;
import com.dayu.daf.core.boot.ctrl.DafController;
import springfox.documentation.annotations.ApiIgnore;

import java.net.URLEncoder;
import java.util.List;
import java.util.Map;

/**
 * 人员信息 控制器
 *
 * @author Daf
 * @since 2024-12-20
 */
@RestController
@AllArgsConstructor
@RequestMapping("/org/staffinfo")
@Api(value = "人员信息", tags = "人员信息接口")
public class StaffInfoController extends DafController {

	private IStaffInfoService staffInfoService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入staffInfo")
	public R<StaffInfoVO> detail(StaffInfo staffInfo) {
		StaffInfoVO detail = staffInfoService.selectDetail(staffInfo.getId());
		return R.data(detail);
	}

	/**
	 * 分页 人员信息
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入staffInfo")
	public R<IPage<StaffInfo>> list(StaffInfo staffInfo, Query query) {
		IPage<StaffInfo> pages = staffInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(staffInfo));
		return R.data(pages);
	}

	/**
	 * 自定义分页 人员信息
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入staffInfo")
	public R<IPage<StaffInfoVO>> page(StaffInfoVO staffInfo, Query query) {
		IPage<StaffInfoVO> pages = staffInfoService.selectStaffInfoPage(Condition.getPage(query), staffInfo);
		return R.data(pages);
	}

	/**
	 * 新增 人员信息
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入staffInfo")
	public R save(@Valid @RequestBody StaffInfo staffInfo) {
		return R.status(staffInfoService.save(staffInfo));
	}

	/**
	 * 修改 人员信息
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入staffInfo")
	public R update(@Valid @RequestBody StaffInfo staffInfo) {
		return R.status(staffInfoService.updateById(staffInfo));
	}

	/**
	 * 新增或修改 人员信息
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入staffInfo")
	public R submit(@Valid @RequestBody StaffInfo staffInfo) {
		return R.status(staffInfoService.saveOrUpdate(staffInfo));
	}


	/**
	 * 删除 人员信息
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(staffInfoService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出
	 */
	@SneakyThrows
	@GetMapping("export")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "导出", notes = "传入")
	@ApiLog
	public void exportUser(@ApiIgnore @RequestParam Map<String, Object> entity, HttpServletResponse response) {
		StaffInfoVO vo = DataUtils.mapToEntity(entity, StaffInfoVO::new);
		List<StaffInfoExcel> list = staffInfoService.export(vo);
		response.setContentType("application/vnd.ms-excel");
		response.setCharacterEncoding(Charsets.UTF_8.name());
		String fileName = URLEncoder.encode("人员管理数据导出", Charsets.UTF_8.name());
		response.setHeader("Content-disposition", "attachment;filename=" + fileName + ".xlsx");
		EasyExcel.write(response.getOutputStream(), StaffInfoExcel.class).sheet("人员管理").doWrite(list);
	}

	/**
	 * 人員性別下拉列表信息
	 */
	@GetMapping("/selectStaffSexInfo")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "下拉", notes = "")
	public List<StaffInfoVO> staffSexSelectInfo(String stationCode) {
		List<StaffInfoVO>  staffSexInfoList= staffInfoService.staffSexInfoData();
		return staffSexInfoList;
	}

	/**
	 * 人員下拉列表信息（值别用）
	 */
	@GetMapping("/selectStaffInfo")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "下拉", notes = "")
	public List<StaffInfoVO> staffSelectInfo(String stationCode) {
		List<StaffInfoVO>  staffInfoList= staffInfoService.staffInfoData();
		return staffInfoList;
	}

}
