/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.org.controller;

import com.xkcoding.http.util.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.swing.text.html.parser.Entity;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.energy.modules.org.vo.PositionInfoVO;
import org.energy.modules.smart.entity.WorkPermit;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.org.entity.StationInfo;
import org.energy.modules.org.vo.StationInfoVO;
import org.energy.modules.org.service.IStationInfoService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;

/**
 * 场站信息 控制器
 *
 * @author Daf
 * @since 2024-12-31
 */
@RestController
@AllArgsConstructor
@RequestMapping("/org/stationinfo")
@Api(value = "场站信息", tags = "场站信息接口")
public class StationInfoController extends DafController {

	private IStationInfoService stationInfoService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入stationInfo")
	public R<StationInfo> detail(StationInfo stationInfo) {
		StationInfo detail = stationInfoService.selectDetail(stationInfo.getId());
		return R.data(detail);
	}

	/**
	 * 分页 场站信息
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入stationInfo")
	public R<IPage<StationInfo>> list(StationInfo stationInfo, Query query) {
		IPage<StationInfo> pages = stationInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(stationInfo));
		return R.data(pages);
	}

	/**
	 * 自定义分页 场站信息
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入stationInfo")
	public R<IPage<StationInfoVO>> page(StationInfoVO stationInfo, Query query) {
		IPage<StationInfoVO> pages = stationInfoService.selectStationInfoPage(Condition.getPage(query), stationInfo);
		return R.data(pages);
	}

	/**
	 * 新增 场站信息
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入stationInfo")
	public R save(@Valid @RequestBody StationInfo stationInfo) {
		return R.status(stationInfoService.save(stationInfo));
	}

	/**
	 * 修改 场站信息
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入stationInfo")
	public R update(@Valid @RequestBody StationInfo stationInfo) {
		return R.status(stationInfoService.updateById(stationInfo));
	}

	/**
	 * 新增或修改 场站信息
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入stationInfo")
	public R submit(@Valid @RequestBody StationInfo stationInfo) {
		String date = LocalDate.now().toString().replace("-","");
		String maxNo = stationInfoService.getMaxNo(date);
		int number;
		if (StringUtil.isNotEmpty(maxNo)){
			number = Integer.parseInt(maxNo.substring(9));
			number++;
		}else{
			number = 1;
		}
		String numFormat = String.format("%04d", number);
		String no = "L" + date + numFormat;

		String id = date + numFormat;
		long formFillerId = Long.parseLong(id);

		stationInfo.setFormFillerId(formFillerId);
		stationInfo.setStationCode(no);
		stationInfo.setStationStatus(1);
		return R.status(stationInfoService.saveOrUpdate(stationInfo));
	}


	/**
	 * 删除 场站信息
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(stationInfoService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 电站下拉列表信息
	 */
	@GetMapping("/selectStationInfo")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "下拉", notes = "")
	public List<StationInfoVO> stationSelectInfo(String stationCode) {
		List<StationInfoVO>  stationInfoList= stationInfoService.stationInfoData(stationCode);
		return stationInfoList;
	}

	/**
	 * 电站下拉列表信息
	 */
	@GetMapping("/selectStationTypeInfo")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "下拉", notes = "")
	public List<StationInfoVO> stationTypeSelectInfo(String stationCode) {
		List<StationInfoVO>  stationTypeInfoList= stationInfoService.stationTypeInfoData(stationCode);
		return stationTypeInfoList;
	}

	/**
	 * 电站下拉列表信息
	 */
	@GetMapping("/selectMaintenanceStatusInfo")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "下拉", notes = "")
	public List<StationInfoVO> maintenanceStatusSelectInfo(String stationCode) {
		List<StationInfoVO>  maintenanceStatusInfoList= stationInfoService.maintenanceStatusInfoData(stationCode);
		return maintenanceStatusInfoList;
	}

	/**
	 * 停用电站一览
	 */
	@PostMapping("/closeStation")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "更新", notes = "传入ids")
	public R closeStation(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		StationInfo stationInfo = new StationInfo();
		stationInfo.setId(Long.parseLong(ids));
		stationInfo.setStationStatus(2);
		return R.status(stationInfoService.updateById(stationInfo));
	}


}
