/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.org.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.energy.modules.org.vo.PositionInfoVO;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.org.entity.TeamInfo;
import org.energy.modules.org.vo.TeamInfoVO;
import org.energy.modules.org.service.ITeamInfoService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.util.List;

/**
 * 班组信息 控制器
 *
 * @author Daf
 * @since 2024-12-25
 */
@RestController
@AllArgsConstructor
@RequestMapping("/org/teaminfo")
@Api(value = "班组信息", tags = "班组信息接口")
public class TeamInfoController extends DafController {

	private ITeamInfoService teamInfoService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入teamInfo")
	public R<TeamInfo> detail(TeamInfo teamInfo) {
		TeamInfo detail = teamInfoService.selectDetail(teamInfo.getId());
		return R.data(detail);
	}

	/**
	 * 分页 班组信息
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入teamInfo")
	public R<IPage<TeamInfo>> list(TeamInfo teamInfo, Query query) {
		IPage<TeamInfo> pages = teamInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(teamInfo));
		return R.data(pages);
	}

	/**
	 * 自定义分页 班组信息
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入teamInfo")
	public R<IPage<TeamInfoVO>> page(TeamInfoVO teamInfo, Query query) {
		IPage<TeamInfoVO> pages = teamInfoService.selectTeamInfoPage(Condition.getPage(query), teamInfo);
		return R.data(pages);
	}

	/**
	 * 新增 班组信息
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入teamInfo")
	public R save(@Valid @RequestBody TeamInfo teamInfo) {
		return R.status(teamInfoService.save(teamInfo));
	}

	/**
	 * 修改 班组信息
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入teamInfo")
	public R update(@Valid @RequestBody TeamInfo teamInfo) {
		return R.status(teamInfoService.updateById(teamInfo));
	}

	/**
	 * 新增或修改 班组信息
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入teamInfo")
	public R submit(@Valid @RequestBody TeamInfo teamInfo) {
		return R.status(teamInfoService.saveOrUpdate(teamInfo));
	}


	/**
	 * 删除 班组信息
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(teamInfoService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 班组下拉列表信息
	 */
	@GetMapping("/selectTeamInfo")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "下拉", notes = "")
	public List<TeamInfoVO> teamSelectInfo(String stationCode) {
		List<TeamInfoVO>  teamInfoList= teamInfoService.teamInfoData(stationCode);
		return teamInfoList;
	}
}
