/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.smart.controller;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.dayu.daf.core.log.annotation.ApiLog;
import com.dayu.daf.core.tool.constant.DafConstant;
import com.xkcoding.http.util.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import lombok.SneakyThrows;
import org.apache.commons.codec.Charsets;
import org.energy.modules.smart.excel.OperationTicketExcel;
import org.energy.modules.system.util.DataUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.smart.entity.OperationTicket;
import org.energy.modules.smart.vo.OperationTicketVO;
import org.energy.modules.smart.service.IOperationTicketService;
import com.dayu.daf.core.boot.ctrl.DafController;
import springfox.documentation.annotations.ApiIgnore;

import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 操作票一览 控制器
 *
 * @author Daf
 * @since 2024-07-10
 */
@RestController
@AllArgsConstructor
@RequestMapping("/smart/operationticket")
@Api(value = "操作票一览", tags = "操作票一览接口")
public class OperationTicketController extends DafController {

	private IOperationTicketService operationTicketService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入operationTicket")
	public R<OperationTicket> detail(OperationTicket operationTicket) {
		OperationTicket detail = operationTicketService.getOne(Condition.getQueryWrapper(operationTicket));
		return R.data(detail);
	}

	/**
	 * 分页 操作票一览
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入operationTicket")
	public R<IPage<OperationTicket>> list(OperationTicket operationTicket, Query query) {
		IPage<OperationTicket> pages = operationTicketService.page(Condition.getPage(query), Condition.getQueryWrapper(operationTicket));
		return R.data(pages);
	}

	/**
	 * 自定义分页 操作票一览
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入operationTicket")
	public R<IPage<OperationTicketVO>> page(OperationTicketVO operationTicket, Query query) {
		IPage<OperationTicketVO> pages = operationTicketService.selectOperationTicketPageExt(Condition.getPage(query), operationTicket);
		return R.data(pages);
	}

	/**
	 * 新增 操作票一览
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入operationTicket")
	public R save(@Valid @RequestBody OperationTicket operationTicket) {
		return R.status(operationTicketService.save(operationTicket));
	}

	/**
	 * 修改 操作票一览
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入operationTicket")
	public R update(@Valid @RequestBody OperationTicket operationTicket) {
		return R.status(operationTicketService.updateById(operationTicket));
	}

	/**
	 * 新增或修改 操作票一览
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入operationTicket")
	public R submit(@Valid @RequestBody OperationTicket operationTicket) {
		return R.status(operationTicketService.saveOrUpdate(operationTicket));
	}


	/**
	 * 删除 操作票一览
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(operationTicketService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 审核 操作票一览
	 */
	@PostMapping("/auditing")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "更新", notes = "传入ids")
	public R auditing(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return this.approve(2,ids);
	}

	/**
	 * 驳回 操作票一览
	 */
	@PostMapping("/reject")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "更新", notes = "传入ids")
	public R reject(@ApiParam(value = "主键集合", required = true) @RequestParam String ids)
	{
		return this.approve(3,ids);
	}

	/**
	 * 驳回OR审核 操作票一览
	 */
	public R approve(Integer status, String ids) {
		List<OperationTicket> list = new ArrayList<>();
		for (String id : ids.split(",")) {
			OperationTicket operationTicket = new OperationTicket();
			operationTicket.setId(Long.parseLong(id));
			operationTicket.setReviewStatus(status);
			list.add(operationTicket);
		}
		return R.status(operationTicketService.updateBatchById(list));
	}
	/**
	 * 失效
	 */
	@PostMapping("/closeticket")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "失效", notes = "传入ids")
	public R lapse(@ApiParam(value = "主键集合", required = true) @RequestParam String ids, @ApiParam(value = "是否合格", required = true) @RequestParam Integer isQuakified,@RequestParam String riskControlEvaluation) {
		return this.updateInspectionRoute(3, isQuakified, ids , riskControlEvaluation);
	}

	/**
	 * 生效OR失效
	 */
	public R updateInspectionRoute(Integer status, Integer isQuakified, String ids , String riskControlEvaluation) {
		List<OperationTicket> list = new ArrayList<>();
		for (String id : ids.split(",")) {
			OperationTicket operationTicket = new OperationTicket();
			operationTicket.setId(Long.parseLong(id));
			operationTicket.setIsQuakified(isQuakified);
			operationTicket.setRiskControlEvaluation(riskControlEvaluation);
			operationTicket.setSts(status);
			list.add(operationTicket);
		}
		return R.status(operationTicketService.updateBatchById(list));
	}
	/**
	 * 导出
	 */
	@SneakyThrows
	@GetMapping("export")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "导出", notes = "传入")
	@ApiLog
	public void exportInspectionRoute(@ApiIgnore @RequestParam Map<String, Object> entity, HttpServletResponse response) {
		entity.remove("daf-auth");
		entity.forEach((key, value) -> {
			if (!"station".equals(key) && !"isQuakified".equals(key) && !"sts".equals(key))
			{
				entity.put(key, "%" + value + "%");
			}
		});
		OperationTicket vo = DataUtils.mapToEntity(entity, OperationTicket::new);

		List<OperationTicketExcel> list = operationTicketService.export(vo);
		response.setContentType("application/vnd.ms-excel");
		response.setCharacterEncoding(Charsets.UTF_8.name());
		String fileName = URLEncoder.encode("操作票数据导出", Charsets.UTF_8.name());
		response.setHeader("Content-disposition", "attachment;filename=" + fileName + ".xlsx");
		EasyExcel.write(response.getOutputStream(), OperationTicketExcel.class).sheet("操作票").doWrite(list);
	}
}
