/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.smart.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.energy.modules.leger.entity.TechParameters;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.smart.entity.WorkPermitAttachment;
import org.energy.modules.smart.vo.WorkPermitAttachmentVO;
import org.energy.modules.smart.service.IWorkPermitAttachmentService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.util.List;

/**
 * 工作票附票一览 控制器
 *
 * @author Daf
 * @since 2024-07-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("/smart/workpermitattachment")
@Api(value = "工作票附票一览", tags = "工作票附票一览接口")
public class WorkPermitAttachmentController extends DafController {

	private IWorkPermitAttachmentService workPermitAttachmentService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入workPermitAttachment")
	public R<WorkPermitAttachment> detail(WorkPermitAttachment workPermitAttachment) {
		WorkPermitAttachment detail = workPermitAttachmentService.getOne(Condition.getQueryWrapper(workPermitAttachment));
		return R.data(detail);
	}

	/**
	 * 分页 工作票附票一览
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入workPermitAttachment")
	public R<IPage<WorkPermitAttachment>> list(WorkPermitAttachment workPermitAttachment, Query query) {
		IPage<WorkPermitAttachment> pages = workPermitAttachmentService.page(Condition.getPage(query), Condition.getQueryWrapper(workPermitAttachment));
		return R.data(pages);
	}

	/**
	 * 自定义分页 工作票附票一览
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入workPermitAttachment")
	public R<IPage<WorkPermitAttachmentVO>> page(WorkPermitAttachmentVO workPermitAttachment, Query query) {
		IPage<WorkPermitAttachmentVO> pages = workPermitAttachmentService.selectWorkPermitAttachmentPage(Condition.getPage(query), workPermitAttachment);
		return R.data(pages);
	}

	/**
	 * 新增 工作票附票一览
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入workPermitAttachment")
	public R save(@Valid @RequestBody WorkPermitAttachment workPermitAttachment) {
		return R.status(workPermitAttachmentService.save(workPermitAttachment));
	}

	/**
	 * 修改 工作票附票一览
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入workPermitAttachment")
	public R update(@Valid @RequestBody WorkPermitAttachment workPermitAttachment) {
		return R.status(workPermitAttachmentService.updateById(workPermitAttachment));
	}

	/**
	 * 新增或修改 工作票附票一览
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入workPermitAttachment")
	public R submit(@Valid @RequestBody WorkPermitAttachment workPermitAttachment) {
		String ticketNo =workPermitAttachment.getTicketCode();
		Integer ticketType =workPermitAttachment.getTicketType();
		Integer maxNo= workPermitAttachmentService.getCount(workPermitAttachment.getWorkTicketNo())+1;
		String ticketIndex  =String.format("%02d", maxNo);
		workPermitAttachment.setTicketCode(ticketNo + ticketType.toString() + ticketIndex);
		return R.status(workPermitAttachmentService.saveOrUpdate(workPermitAttachment));
	}

	/**
	 * 删除 工作票附票一览
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(workPermitAttachmentService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 列表 技术参数一览
	 */
	@GetMapping("/getList")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "列表", notes = "workPermitAttachment")
	public R<List<WorkPermitAttachment>> getList(WorkPermitAttachment workPermitAttachment) {
		List<WorkPermitAttachment> list = workPermitAttachmentService.list(Condition.getQueryWrapper(workPermitAttachment));
		return R.data(list);
	}
}
