/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.smart.controller;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.dayu.daf.core.log.annotation.ApiLog;
import com.dayu.daf.core.tool.constant.DafConstant;
import com.xkcoding.http.util.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import lombok.SneakyThrows;
import org.apache.commons.codec.Charsets;
import org.energy.modules.leger.entity.EquipmentLedger;
import org.energy.modules.leger.excel.EquipmentLedgerExcel;
import org.energy.modules.smart.excel.WorkOrderExcel;
import org.energy.modules.smart.excel.WorkPermitExcel;
import org.energy.modules.smart.service.IWorkPermitAttachmentService;
import org.energy.modules.smart.vo.WorkOrderVO;
import org.energy.modules.system.util.DataUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.smart.entity.WorkPermit;
import org.energy.modules.smart.vo.WorkPermitVO;
import org.energy.modules.smart.service.IWorkPermitService;
import com.dayu.daf.core.boot.ctrl.DafController;
import springfox.documentation.annotations.ApiIgnore;

import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 工作票一览 控制器
 *
 * @author Daf
 * @since 2024-07-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("/smart/workpermit")
@Api(value = "工作票一览", tags = "工作票一览接口")
public class WorkPermitController extends DafController {

	private IWorkPermitService workPermitService;
	private IWorkPermitAttachmentService workPermitAttachmentService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入workPermit")
	public R<WorkPermit> detail(WorkPermit workPermit) {
		WorkPermit detail = workPermitService.getOne(Condition.getQueryWrapper(workPermit));
		return R.data(detail);
	}

	/**
	 * 分页 工作票一览
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入workPermit")
	public R<IPage<WorkPermit>> list(WorkPermitVO workPermit, Query query) {
		QueryWrapper<WorkPermit> qw = new QueryWrapper<>();
		//场站
		if (null != workPermit.getStations()) {
			qw.lambda().eq(WorkPermit::getStations, workPermit.getStations());
		}
		//工作票编号
		if (StringUtil.isNotEmpty(workPermit.getWorkTicketNo())) {
			qw.lambda().like(WorkPermit::getWorkTicketNo, workPermit.getWorkTicketNo());
		}
		//工作票类型
		if (StringUtil.isNotEmpty(workPermit.getWorkTicketType())) {
			qw.lambda().like(WorkPermit::getWorkTicketType, workPermit.getWorkTicketType());
		}
		//状态
		if (null != workPermit.getWorkState()) {
			qw.lambda().eq(WorkPermit::getWorkState, workPermit.getWorkState());
		}
		//许可人
		if (StringUtil.isNotEmpty(workPermit.getLicensors())) {
			qw.lambda().like(WorkPermit::getLicensors, workPermit.getLicensors());
		}
		//签发人
		if (StringUtil.isNotEmpty(workPermit.getIssuer())) {
			qw.lambda().like(WorkPermit::getIssuer, workPermit.getIssuer());
		}

		//工作负责人
		if (StringUtil.isNotEmpty(workPermit.getWorkChargePerson())) {
			qw.lambda().like(WorkPermit::getWorkChargePerson, workPermit.getWorkChargePerson());
		}

		//计划开始时间
		if (null != workPermit.getPlanStartDateExt()) {
			String planStartDate = workPermit.getPlanStartDateExt().substring(0,10);
			qw.lambda().last(" and plan_start_date >= TO_TIMESTAMP('"+planStartDate + " 00:00:00','YYYY-MM-DD HH24:MI:SS')");
		}
		IPage<WorkPermit> pages = workPermitService.page(Condition.getPage(query), qw);
		return R.data(pages);
	}

	/**
	 * 自定义分页 工作票一览
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入workPermit")
	public R<IPage<WorkPermitVO>> page(WorkPermitVO workPermit, Query query) {
		IPage<WorkPermitVO> pages = workPermitService.selectWorkPermitPage(Condition.getPage(query), workPermit);
		return R.data(pages);
	}

	/**
	 * 新增 工作票一览
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入workPermit")
	public R save(@Valid @RequestBody WorkPermit workPermit) {
		return R.status(workPermitService.save(workPermit));
	}

	/**
	 * 修改 工作票一览
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入workPermit")
	public R update(@Valid @RequestBody WorkPermit workPermit) {
		return R.status(workPermitService.updateById(workPermit));
	}

	/**
	 * 新增或修改 工作票一览
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入workPermit")
	public R submit(@Valid @RequestBody WorkPermit workPermit) {
		return R.status(workPermitService.saveOrUpdate(workPermit));
	}

	/**
	 * 删除 工作票一览
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		for (String id : ids.split(",")) {
			workPermitAttachmentService.delWorkPermitAttachment(Long.parseLong(id));
		}
		return R.status(workPermitService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 审核 工作票一览
	 */
	@PostMapping("/auditing")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "更新", notes = "传入ids")
	public R auditing(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return this.approve(2,ids);
	}

	/**
	 * 驳回 工作票一览
	 */
	@PostMapping("/reject")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "更新", notes = "传入ids")
	public R reject(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return this.approve(3,ids);
	}

	/**
	 * 驳回OR审核 工作票一览
	 */
	public R approve(Integer status, String ids) {
		List<WorkPermit> list = new ArrayList<>();
		for (String id : ids.split(",")) {
			WorkPermit workPermit = new WorkPermit();
			workPermit.setId(Long.parseLong(id));
			workPermit.setCheckStatus(status);
			list.add(workPermit);
		}
		return R.status(workPermitService.updateBatchById(list));
	}

	/**
	 * 导出
	 */
	@SneakyThrows
	@GetMapping("export")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "导出", notes = "传入")
	@ApiLog
	public void exportUser(@ApiIgnore @RequestParam Map<String, Object> entity, HttpServletResponse response) {
		WorkPermitVO vo = DataUtils.mapToEntity(entity, WorkPermitVO::new);
		List<WorkPermitExcel> list = workPermitService.export(vo);
		response.setContentType("application/vnd.ms-excel");
		response.setCharacterEncoding(Charsets.UTF_8.name());
		String fileName = URLEncoder.encode("工作票数据导出", Charsets.UTF_8.name());
		response.setHeader("Content-disposition", "attachment;filename=" + fileName + ".xlsx");
		EasyExcel.write(response.getOutputStream(), WorkPermitExcel.class).sheet("工作票").doWrite(list);
	}

	/**
	 * 关票工作票一览
	 */
	@PostMapping("/closeTicket")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "更新", notes = "传入ids")
	public R closeTicket(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		List<WorkPermit> list = new ArrayList<>();
		for (String id : ids.split(",")) {
			WorkPermit workPermit = new WorkPermit();
			workPermit.setId(Long.parseLong(id));
			workPermit.setWorkState(4);
			list.add(workPermit);
		}
		return R.status(workPermitService.updateBatchById(list));
	}
}

