/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.spares.controller;

import com.xkcoding.http.util.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import lombok.Data;
import org.energy.modules.leger.entity.TechParameters;
import org.energy.modules.spares.service.IMaterialService;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.spares.entity.Inbound;
import org.energy.modules.spares.vo.InboundVO;
import org.energy.modules.spares.service.IInboundService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

/**
 * 入库 控制器
 *
 * @author Daf
 * @since 2024-07-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("/spares/inbound")
@Api(value = "入库", tags = "入库接口")
public class InboundController extends DafController {

	private IInboundService inboundService;
	private IMaterialService materialService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入inbound")
	public R<Inbound> detail(Inbound inbound) {
		Inbound detail = inboundService.getOne(Condition.getQueryWrapper(inbound));
		return R.data(detail);
	}

	/**
	 * 分页 入库
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入inbound")
	public R<IPage<Inbound>> list(Inbound inbound, Query query) {
		IPage<Inbound> pages = inboundService.page(Condition.getPage(query), Condition.getQueryWrapper(inbound));
		return R.data(pages);
	}

	/**
	 * 自定义分页 入库
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入inbound")
	public R<IPage<InboundVO>> page(InboundVO inbound, Query query) {
		IPage<InboundVO> pages = inboundService.selectInboundPage(Condition.getPage(query), inbound);
		return R.data(pages);
	}

	/**
	 * 新增 入库
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入inbound")
	public R save(@Valid @RequestBody Inbound inbound) {
		return R.status(inboundService.save(inbound));
	}

	/**
	 * 修改 入库
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入inbound")
	public R update(@Valid @RequestBody Inbound inbound) {
		if (inbound.getIstatus() == 2)
		{
			materialService.updateNum(inbound.getMaterialNo(), inbound.getInboundCount());
		}
		return R.status(inboundService.updateById(inbound));
	}

	/**
	 * 新增或修改 入库
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入inbound")
	public R submit(@Valid @RequestBody Inbound inbound) {
		String maxNo = inboundService.getMaxNo("'%" + inbound.getMaterialNo() + "%'");
		int number;
		if (StringUtil.isNotEmpty(maxNo)){
			number = Integer.parseInt(maxNo.substring(10));
			number++;
		}else{
			number = 1;
		}
		String numFormat = String.format("%06d", number);
		String no = inbound.getMaterialNo() + "IN" + numFormat;
		inbound.setInboundNo(no);
		Date date = new Date();
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
		String time = sdf.format(date);
		inbound.setInboundTime(time);
		inbound.setIstatus(1L);
		return R.status(inboundService.saveOrUpdate(inbound));
	}


	/**
	 * 删除 入库
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(inboundService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 列表 入库详细
	 */
	@GetMapping("/getList")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "列表", notes = "传入inbound")
	public R<List<Inbound>> getList(Inbound inbound) {
		List<Inbound> list = inboundService.list(Condition.getQueryWrapper(inbound));
		return R.data(list);
	}


}
