/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.spares.controller;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.dayu.daf.core.log.annotation.ApiLog;
import com.dayu.daf.core.tool.constant.DafConstant;
import io.micrometer.core.instrument.util.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import lombok.SneakyThrows;
import org.apache.commons.codec.Charsets;
import org.energy.modules.spares.excel.MaterialClassExcel;
import org.energy.modules.system.util.DataUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.spares.entity.MaterialClassification;
import org.energy.modules.spares.vo.MaterialClassificationVO;
import org.energy.modules.spares.service.IMaterialClassificationService;
import com.dayu.daf.core.boot.ctrl.DafController;
import springfox.documentation.annotations.ApiIgnore;

import java.net.URLEncoder;
import java.util.List;
import java.util.Map;

/**
 * spt_material_classification 控制器
 *
 * @author Daf
 * @since 2024-07-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("/materialclassification")
@Api(value = "spt_material_classification", tags = "spt_material_classification接口")
public class MaterialClassificationController extends DafController {

	private IMaterialClassificationService materialClassificationService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入materialClassification")
	public R<MaterialClassification> detail(MaterialClassification materialClassification) {
		MaterialClassification detail = materialClassificationService.getOne(Condition.getQueryWrapper(materialClassification));
		return R.data(detail);
	}

	/**
	 * 分页 spt_material_classification
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入materialClassification")
	public R<IPage<MaterialClassification>> list(MaterialClassification materialClassification, Query query) {
		QueryWrapper<MaterialClassification> qw = new QueryWrapper<>();
		if (StringUtils.isNotEmpty(materialClassification.getCode())) {
			qw.lambda().like(MaterialClassification::getCode, materialClassification.getCode());
		}
		if (materialClassification.getType() != null) {
			qw.lambda().like(MaterialClassification::getType, materialClassification.getType());
		}
		qw.lambda().eq(MaterialClassification::getIsDeleted, DafConstant.DB_NOT_DELETED);
		qw.lambda().orderByDesc(MaterialClassification::getUpdateTime);
		IPage<MaterialClassification> pages = materialClassificationService.page(Condition.getPage(query), qw);
		return R.data(pages);
	}

	/**
	 * 自定义分页 spt_material_classification
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入materialClassification")
	public R<IPage<MaterialClassificationVO>> page(MaterialClassificationVO materialClassification, Query query) {
		IPage<MaterialClassificationVO> pages = materialClassificationService.selectMaterialClassificationPage(Condition.getPage(query), materialClassification);
		return R.data(pages);
	}

	/**
	 * 新增 spt_material_classification
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入materialClassification")
	public R save(@Valid @RequestBody MaterialClassification materialClassification) {
		return R.status(materialClassificationService.save(materialClassification));
	}

	/**
	 * 修改 spt_material_classification
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入materialClassification")
	public R update(@Valid @RequestBody MaterialClassification materialClassification) {
		return R.status(materialClassificationService.updateById(materialClassification));
	}

	/**
	 * 新增或修改 spt_material_classification
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入materialClassification")
	public R submit(@Valid @RequestBody MaterialClassification materialClassification) {
		return R.status(materialClassificationService.saveOrUpdate(materialClassification));
	}


	/**
	 * 删除 spt_material_classification
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(materialClassificationService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出
	 */
	@SneakyThrows
	@GetMapping("export")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "导出", notes = "传入")
	@ApiLog
	public void exportUser(@ApiIgnore @RequestParam Map<String, Object> entity, HttpServletResponse response) {
		entity.remove("daf-auth");
		MaterialClassificationVO vo = DataUtils.mapToEntity(entity, MaterialClassificationVO::new);
		List<MaterialClassExcel> list = materialClassificationService.export(vo);
		response.setContentType("application/vnd.ms-excel");
		response.setCharacterEncoding(Charsets.UTF_8.name());
		String fileName = URLEncoder.encode("物资分类码数据导出", Charsets.UTF_8.name());
		response.setHeader("Content-disposition", "attachment;filename=" + fileName + ".xlsx");
		EasyExcel.write(response.getOutputStream(), MaterialClassExcel.class).sheet("物资分类码").doWrite(list);
	}

	/**
	 * 分页 物资分类码
	 */
	@GetMapping("/getCodeList")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "获取物资分类码", notes = "获取物资分类码")
	public R<List<String>> getCodeList() {
		List<String> list = materialClassificationService.getCodeList();
		return R.data(list);
	}


}
