/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.spares.excel;

import com.alibaba.excel.annotation.ExcelProperty;
import com.alibaba.excel.annotation.write.style.ColumnWidth;
import com.alibaba.excel.annotation.write.style.ContentRowHeight;
import com.alibaba.excel.annotation.write.style.HeadRowHeight;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.NullSerializer;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;

/**
 * Warehouse model export
 * @author edwong
 */
@Data
@ColumnWidth(25)
@HeadRowHeight(20)
@ContentRowHeight(16)
public class ManufacturerInfoExcel implements Serializable {
	private static final long serialVersionUID = 1L;

	/**
	 * 统一社会信用代码/组织机构
	 */
	@ColumnWidth(20)
	@ExcelProperty(value = "统一社会信用代码/组织机构")
	private String creditCode;
	/**
	 * 制造商名称
	 */
	@ColumnWidth(20)
	@ExcelProperty(value = "制造商名称")
	private String manufacturerName;
	/**
	 * 注册地址
	 */
	@ColumnWidth(20)
	@ExcelProperty(value = "注册地址")
	private String registeredAddress;
	/**
	 * 生产地址
	 */
	@ColumnWidth(20)
	@ExcelProperty(value = "生产地址")
	private String productionAddress;
	/**
	 * 联系电话
	 */
	@ColumnWidth(20)
	@ExcelProperty(value = "联系电话")
	private String contactNumber;
	/**
	 * 电子邮箱
	 */
	@ColumnWidth(20)
	@ExcelProperty(value = "电子邮箱")
	private String email;
	/**
	 * 经营范围
	 */
	@ColumnWidth(20)
	@ExcelProperty(value = "经营范围")
	private String businessScope;
	/**
	 * 执行标准
	 */
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ColumnWidth(20)
	@ExcelProperty(value = "执行标准")
	private String executiveStandards;

	/**
	 * 审核状态
	 */
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ColumnWidth(20)
	@ExcelProperty(value = "审核状态")
	private String approvalStatus;

}
