/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.system.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.system.entity.Demo;
import org.energy.modules.system.vo.DemoVO;
import org.energy.modules.system.service.IDemoService;
import com.dayu.daf.core.boot.ctrl.DafController;

/**
 *  控制器
 *
 * @author Daf
 * @since 2024-10-25
 */
@RestController
@AllArgsConstructor
@RequestMapping("/system/demo")
@Api(value = "", tags = "接口")
public class DemoController extends DafController {

	private IDemoService demoService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入demo")
	public R<Demo> detail(Demo demo) {
		Demo detail = demoService.getOne(Condition.getQueryWrapper(demo));
		return R.data(detail);
	}

	/**
	 * 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入demo")
	public R<IPage<Demo>> list(Demo demo, Query query) {
		IPage<Demo> pages = demoService.page(Condition.getPage(query), Condition.getQueryWrapper(demo));
		return R.data(pages);
	}

	/**
	 * 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入demo")
	public R<IPage<DemoVO>> page(DemoVO demo, Query query) {
		IPage<DemoVO> pages = demoService.selectDemoPage(Condition.getPage(query), demo);
		return R.data(pages);
	}

	/**
	 * 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入demo")
	public R save(@Valid @RequestBody Demo demo) {
		return R.status(demoService.save(demo));
	}

	/**
	 * 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入demo")
	public R update(@Valid @RequestBody Demo demo) {
		return R.status(demoService.updateById(demo));
	}

	/**
	 * 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入demo")
	public R submit(@Valid @RequestBody Demo demo) {
		return R.status(demoService.saveOrUpdate(demo));
	}


	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(demoService.deleteLogic(Func.toLongList(ids)));
	}


}
