package org.energy.modules.system.controller;

import com.alibaba.fastjson.JSON;
import com.dayu.daf.core.log.exception.ServiceException;
import com.dayu.daf.core.tool.api.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.energy.modules.auth.utils.TokenUtil;
import org.energy.modules.system.config.DataConfig;
import org.energy.modules.system.service.IDeptService;
import org.energy.modules.system.service.IFileService;
import org.energy.modules.system.util.DateTimeUtils;
import org.energy.modules.system.util.EnumFileInfoType;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

/**
 * Created by edwong on 2024/7/8.
 * 文件控制器
 */
@RestController
@RequestMapping("/system/file")
@AllArgsConstructor
@ApiIgnore
@Slf4j
@Api(value = "文件", tags = "文件")
public class FileController {

	@Autowired
	DataConfig dataConfig;

	@Autowired
	private IFileService fileService;


	/**
     * 附件上载
     */
    @ApiOperation("附件上载")
    @PostMapping(value = "/upload")
    public R upload(@RequestPart("file") MultipartFile picture,
                    @RequestParam("fileType") String fileType) {
		Map<String, Object> resultMap = new HashMap<>();
		try {
			if (null != picture) {
				String sUniqueNewImageName = UUID.randomUUID().toString();
				String sOriginalFilename = picture.getOriginalFilename();//picture.getOriginalFilename();
				int suffixIndex = sOriginalFilename.lastIndexOf(".");
				String suffix = "";
				if (suffixIndex > 0) {
					suffix = sOriginalFilename.substring(suffixIndex);
				}
				String fileSavePath = dataConfig.getUploadPath();
				fileSavePath = fileSavePath + EnumFileInfoType.getKeyDesc(fileType) + "/" + DateTimeUtils.getFormatDate(new Date(), DateTimeUtils.YEAR_MONTH_DATE_FORMAT) + "/";

				String filePath = "/data/actual/" + EnumFileInfoType.getKeyDesc(fileType) + "/" + DateTimeUtils.getFormatDate(new Date(), DateTimeUtils.YEAR_MONTH_DATE_FORMAT) + "/";
				if (!new File(fileSavePath).exists()) {
					new File(fileSavePath).mkdirs();
				}
				picture.transferTo(new File(fileSavePath + sUniqueNewImageName + suffix));

				resultMap = fileService.saveFileInfo(fileType, filePath, sUniqueNewImageName, suffix, sOriginalFilename);
			}
		} catch (Exception e) {
			log.error(e.getMessage(), e);
			throw new ServiceException("上传图片出错");
		}
		return R.data(resultMap);
	}

	/**
	 * 附件上载
	 */
	@ApiOperation("附件下载")
	@GetMapping(value = "/download")
	@ResponseBody
	public void download(@RequestParam("fileName") String fileName, HttpServletResponse response) {
		fileService.downloadFile(fileName, response);
	}

}


