/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.system.controller;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.dayu.daf.core.log.model.LogApi;
import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.BeanUtil;
import com.dayu.daf.core.tool.utils.Func;
import com.dayu.daf.core.tool.utils.StringPool;
import lombok.AllArgsConstructor;
import org.energy.modules.system.entity.User;
import org.energy.modules.system.service.ILogApiService;
import org.energy.modules.system.service.IUserService;
import org.energy.modules.system.vo.LogApiRVo;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import springfox.documentation.annotations.ApiIgnore;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 控制器
 *
 * @author Chill
 */
@ApiIgnore
@RestController
@AllArgsConstructor
@RequestMapping("/daf-log/api")
public class LogApiController {

	private ILogApiService logService;

	private IUserService userService;

	/**
	 * 查询单条
	 */
	@GetMapping("/detail")
	public R<LogApiRVo> detail(LogApi log) {
		LogApi logApi = logService.getOne(Condition.getQueryWrapper(log));
		LogApiRVo vo = BeanUtil.copy(logApi, LogApiRVo.class);
		User user = userService.selectByAccountAndDel(vo.getCreateBy());
		if (user != null) {
			vo.setCreateUserName(user.getName());
		}
		return R.data(vo);
	}

	/**
	 * 查询多条(分页)
	 */
	@GetMapping("/list")
	public R<IPage<LogApiRVo>> list(@ApiIgnore @RequestParam Map<String, Object> log, Query query) {
		query.setAscs(StringPool.EMPTY);
		query.setDescs("create_time");
		IPage<LogApi> pages = logService.page(Condition.getPage(query), Condition.getQueryWrapper(log, LogApi.class));
		List<LogApiRVo> records = pages.getRecords().stream().map(logApi -> {
			LogApiRVo vo = BeanUtil.copy(logApi, LogApiRVo.class);
			vo.setStrId(Func.toStr(logApi.getId()));
			User user = userService.selectByAccountAndDel(vo.getCreateBy());
			if (user != null) {
				vo.setCreateUserName(user.getName());
			}
			return vo;
		}).collect(Collectors.toList());
		IPage<LogApiRVo> pageVo = new Page<>(pages.getCurrent(), pages.getSize(), pages.getTotal());
		pageVo.setRecords(records);
		return R.data(pageVo);
	}

}
