package org.energy.modules.system.util;

import org.energy.modules.system.vo.OperatingModeDetailVO;
import org.energy.modules.system.vo.SimulationDetailVO;

import java.lang.reflect.Field;
import java.math.BigDecimal;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;

public class ReflectionUtils {
	public static Map<String, BigDecimal> extractEleCostFieldMap(Map<Integer, String> dictMap, OperatingModeDetailVO vo, String suffix) throws NoSuchFieldException, IllegalAccessException {
		Map<String, BigDecimal> dates = new HashMap<>(24);
		Class<OperatingModeDetailVO> clazz = (Class<OperatingModeDetailVO>) vo.getClass();
		String key;
		String fieldName;
		String fieldTypeName;
		String fieldTypeCoef;

		for (int i = 1; i <= 24; i++) {
			key = getDate(i);
			fieldName = key + suffix;
			fieldTypeName = key + "Type";
			Field field = clazz.getDeclaredField(fieldName);
			field.setAccessible(true); // 允许访问私有字段
			Field fieldType = clazz.getDeclaredField(fieldTypeName);
			fieldType.setAccessible(true); // 允许访问私有字段
			fieldTypeCoef = dictMap.get(Integer.parseInt(fieldType.get(vo).toString()));
			if ("purchasePrice".equals(fieldTypeCoef)) {
				Field fieldCoef = clazz.getDeclaredField(fieldTypeCoef);
				fieldCoef.setAccessible(true); // 允许访问私有字段
				// 获取字段的值并转换为 BigDecimal
				BigDecimal userPower = (BigDecimal) field.get(vo);
				BigDecimal unitPrice = (BigDecimal) fieldCoef.get(vo);
				dates.put(key, userPower.multiply(unitPrice));
			} else {
				Field fieldCoef = clazz.getDeclaredField(fieldTypeCoef);
				fieldCoef.setAccessible(true); // 允许访问私有字段
				// 获取字段的值并转换为 BigDecimal
				BigDecimal userPower = (BigDecimal) field.get(vo);
				BigDecimal unitPrice = (BigDecimal) fieldCoef.get(vo);
				dates.put(key, userPower.multiply(unitPrice.multiply(vo.getPurchasePrice())));
			}
		}

		// 如果你想要自定义排序顺序，可以传递一个Comparator给TreeMap
		Comparator<String> dateComparator = (key1, key2) -> {
			int num1 = Integer.parseInt(key1.substring(4)); // 键的格式是"dateX"，其中X是数字
			int num2 = Integer.parseInt(key2.substring(4));
			return Integer.compare(num1, num2);
		};
		Map<String, BigDecimal> sortedMap = new TreeMap<>(dateComparator);
		sortedMap.putAll(dates);

		return sortedMap;
	}

	public static Map<String, BigDecimal> extractCoeffFieldMap(Map<Integer, String> dictMap, OperatingModeDetailVO vo) throws NoSuchFieldException, IllegalAccessException {
		Map<String, BigDecimal> dates = new HashMap<>(24);
		Class<OperatingModeDetailVO> clazz = (Class<OperatingModeDetailVO>) vo.getClass();
		String key;
		String fieldName;
		String fieldTypeName;
		String fieldTypeCoef;

		for (int i = 1; i <= 24; i++) {
			key = getDate(i);
			fieldTypeName = key + "Type";
			Field fieldType = clazz.getDeclaredField(fieldTypeName);
			fieldType.setAccessible(true); // 允许访问私有字段
			fieldTypeCoef = dictMap.get(Integer.parseInt(fieldType.get(vo).toString()));
			if ("purchasePrice".equals(fieldTypeCoef)) {
				Field fieldCoef = clazz.getDeclaredField(fieldTypeCoef);
				fieldCoef.setAccessible(true); // 允许访问私有字段
				// 获取字段的值并转换为 BigDecimal
				BigDecimal unitPrice = (BigDecimal) fieldCoef.get(vo);
				dates.put(key, unitPrice);
			} else {
				Field fieldCoef = clazz.getDeclaredField(fieldTypeCoef);
				fieldCoef.setAccessible(true); // 允许访问私有字段
				// 获取字段的值并转换为 BigDecimal
				BigDecimal unitPrice = (BigDecimal) fieldCoef.get(vo);
				dates.put(key, unitPrice.multiply(vo.getPurchasePrice()));
			}
		}

		return dates;
	}

	public static Map<String, BigDecimal> extractUserPowerFieldMap(OperatingModeDetailVO vo, String suffix) throws NoSuchFieldException, IllegalAccessException {
		Map<String, BigDecimal> dates = new HashMap<>(24);
		Class<OperatingModeDetailVO> clazz = (Class<OperatingModeDetailVO>) vo.getClass();
		String fieldName;
		String key;

		for (int i = 1; i <= 24; i++) {
			key = "date" + i;
			fieldName = "date" + i + suffix;
			Field field = clazz.getDeclaredField(fieldName);
			field.setAccessible(true); // 允许访问私有字段
			dates.put(key, (BigDecimal) field.get(vo));
		}

		return dates;
	}

	public static Map<String, BigDecimal> extractOpticalPowerFieldMap(OperatingModeDetailVO vo, String suffix) throws NoSuchFieldException, IllegalAccessException {
		Map<String, BigDecimal> dates = new HashMap<>(24);
		Class<OperatingModeDetailVO> clazz = (Class<OperatingModeDetailVO>) vo.getClass();
		String fieldName;
		String key;
		BigDecimal outputRatio = vo.getOutputRatio();
		for (int i = 1; i <= 24; i++) {
			key = getDate(i);
			fieldName = "date" + i + suffix;
			Field field = clazz.getDeclaredField(fieldName);
			field.setAccessible(true); // 允许访问私有字段
			BigDecimal opticalPower = (BigDecimal) field.get(vo);
			dates.put(key, opticalPower.multiply(outputRatio));
		}

		return dates;
	}

	public static void setValue(OperatingModeDetailVO vo, String filedName, SimulationDetailVO simulationDetailVO) throws NoSuchFieldException, IllegalAccessException {
		Class<OperatingModeDetailVO> clazz = (Class<OperatingModeDetailVO>) vo.getClass();
		Field field = clazz.getDeclaredField(filedName);
		field.setAccessible(true); // 允许访问私有字段
		field.set(vo, simulationDetailVO);
	}

	public static Object getValue(OperatingModeDetailVO vo, String filedName) throws NoSuchFieldException, IllegalAccessException {
		Class<OperatingModeDetailVO> clazz = (Class<OperatingModeDetailVO>) vo.getClass();
		Field field = clazz.getDeclaredField(filedName);
		field.setAccessible(true); // 允许访问私有字段
		return field.get(vo);
	}

	public static String getDate(int index) {
		return "date" + index;
	}
}
